# Error Handling in GraphQL
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql#overview)
  * [Error Handling in SAP LeanIX GraphQL](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql#error-handling-in-sap-leanix-graphql)
  * [Error Handling for Batch Mutations](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql#error-handling-for-batch-mutations)
  * [Handling Errors in Your Application](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql#handling-errors-in-your-application)


Learn how error handling in GraphQL works and how to manage GraphQL errors.
